@@ -8,7 +8,7 @@ with codecs.open("README.rst", encoding='utf8') as fh:
 setuptools.setup(name='metacountregressor',
                  version='0.1.63',
                  description='Extensions for a Python package for \
-                              GPU-accelerated estimation of mixed logit models.',
+                             estimation of data count models.',
                  long_description=long_description,
                  long_description_content_type="text/x-rst",
                  url='https://github.com/zahern/CountDataEstimation',
@@ -20,5 +20,6 @@ setuptools.setup(name='metacountregressor',
                  python_requires='>=3.10',
                  install_requires=[
                      'numpy>=1.13.1',
-                     'scipy>=1.0.0'
+                     'scipy>=1.0.0',
+                     'latextable'
                  ])
\ No newline at end of file
